#########################################################
GR - a universal framework for visualization applications
#########################################################

GR is a universal framework for cross-platform visualization applications.
It offers developers a compact, portable and consistent graphics library for
their programs. Applications range from publication quality 2D graphs to the
representation of complex 3D scenes.

GR is essentially based on an implementation of a Graphical Kernel System (GKS)
and OpenGL. As a self-contained system it can quickly and easily be integrated
into existing applications (i.e. using the ctypes mechanism in Python).
The GR framework can be used in imperative programming systems or integrated
into modern object-oriented systems, in particular those based on GUI toolkits.
GR is characterized by its high interoperability and can be used with modern
web technologies and mobile devices. The GR framework is especially suitable
for real-time environments.

GR was developed by the Scientific IT-Systems group at the Peter Grünberg
Institute at Forschunsgzentrum Jülich. The main development has been done
by Josef Heinen who currently maintains the software, but there are other
developers who currently make valuable contributions. Special thanks to
Florian Rhiem (GR3) and Christian Felder (qtgr, setup.py).

For further information please refer to the `GR home page <http://gr-framework.org/>`_.
 
